@@ -6,7 +6,7 @@ from fabric.decorators import runs_once
 @runs_once
 def pre_deploy(branch=None):
     """
-    Make sure that local.deploy.prep is only run
+    Make sure that ``local.deploy.prep`` is only run
     once when the deploy command is run on multiple
     hosts.
     """
@@ -19,7 +19,7 @@ def deploy(branch=None):
     Deploy this project.
 
     Internally calls local.deploy.prep once and then
-    local.deploy.do for each host.
+    ``local.deploy.do`` for each host.
 
     Takes an optional branch argument that can be used
     to deploy a branch other than master.
