@@ -1,6 +1,7 @@
 import subprocess
 import urlparse
 import os
+import random
 
 from fabric.api import env
 from fabric.task_utils import crawl
@@ -84,3 +85,30 @@ def get_task_instance(name):
     """
     from fabric import state
     return crawl(name, state.commands)
+
+def random_password(bit=12):
+    """
+    generate a password randomly which include
+    numbers, letters and sepcial characters
+    """
+    numbers = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9']
+    small_letters = [chr(i) for i in range(97, 123)]
+    cap_letters = [chr(i) for i in range(65, 91)]
+    special = ['@', '#', '$', '%', '^', '&', '*', '-']
+
+    passwd = []
+    for i in range(bit/4):
+        passwd.append(random.choice(numbers))
+        passwd.append(random.choice(small_letters))
+        passwd.append(random.choice(cap_letters))
+        passwd.append(random.choice(special))
+    for i in range(bit%4):
+        passwd.append(random.choice(numbers))
+        passwd.append(random.choice(small_letters))
+        passwd.append(random.choice(cap_letters))
+        passwd.append(random.choice(special))
+
+    passwd = passwd[:bit]
+    random.shuffle(passwd)
+
+    return ''.join(passwd)
