@@ -12,7 +12,8 @@ from fabric.context_managers import cd
 
 from fabric.tasks import Task
 
-from utils import random_password
+from fab_deploy.functions import random_password
+import utils
 
 class PostgresInstall(Task):
     """
@@ -74,7 +75,7 @@ class PostgresInstall(Task):
         else:
             print ('Could not find file %s. Please make sure postgresql was '
                    'installed and data dir was created correctly.'%hba_conf)
-            sys.exit()
+            sys.exit(1)
 
     def _setup_postgres_config(self, data_dir=None, config=None):
         postgres_conf = os.path.join(data_dir, 'postgresql.conf')
@@ -84,7 +85,7 @@ class PostgresInstall(Task):
         else:
             print ('Could not find file %s. Please make sure postgresql was '
                    'installed and data dir was created correctly.' %postgres_conf)
-            sys.exit()
+            sys.exit(1)
 
     def _setup_archive_dir(self, data_dir):
         archive_dir = os.path.join(data_dir, 'wal_archive')
@@ -96,16 +97,19 @@ class PostgresInstall(Task):
     def _setup_ssh_key(self):
         ssh_dir = '/var/pgsql/.ssh'
 
-        sudo('mkdir -p %s' %ssh_dir)
-        sudo('chown -R postgres:postgres %s' %ssh_dir)
-        sudo('chmod -R og-rwx %s' %ssh_dir)
         rsa = os.path.join(ssh_dir, 'id_rsa')
-        run('sudo su postgres -c "ssh-keygen -t rsa -f %s -N \'\'"' %rsa)
+        if exists(rsa):
+            print "rsa key exists, skipping creating"
+        else:
+            sudo('mkdir -p %s' %ssh_dir)
+            sudo('chown -R postgres:postgres %s' %ssh_dir)
+            sudo('chmod -R og-rwx %s' %ssh_dir)
+            run('sudo su postgres -c "ssh-keygen -t rsa -f %s -N \'\'"' %rsa)
 
     def _restart_db_server(self, db_version):
         sudo('svcadm restart postgresql:pg%s' %db_version)
 
-    def _create_user(self):
+    def _create_user(self, section):
         username = raw_input("Now we are creating the database user, please "
                              "specify a username: ")
         # 'postgres' is postgresql superuser
@@ -119,11 +123,11 @@ class PostgresInstall(Task):
         else:
             run("sudo su postgres -c 'createuser -D -S -R -P %s'" %username)
 
-        env.config_object.set('db-server', env.config_object.USERNAME, username)
+        env.config_object.set(section, env.config_object.USERNAME, username)
 
         return username
 
-    def _create_replicator(self, db_version):
+    def _create_replicator(self, db_version, section):
         db_out = run("echo '\du replicator' | sudo su postgres -c 'psql'")
         if 'replicator' not in db_out:
             replicator_pass = random_password(12)
@@ -134,17 +138,17 @@ class PostgresInstall(Task):
             history_file = os.path.join('/var', 'pgsql', '.psql_history')
             if exists(history_file):
                 sudo('rm %s' %history_file)
+            env.config_object.set(section, env.config_object.REPLICATOR,
+                                  'replicator')
+            env.config_object.set(section, env.config_object.REPLICATOR_PASS,
+                                  replicator_pass)
+            return replicator_pass
         else:
             print "user replicator already exists, skipping creating user."
+            return None
 
-            env.config_object.set('db-server', env.config_object.REPLICATOR,
-                                  'replicator')
-            env.config_object.set('db-server', env.config_object.REPLICATOR_PASS,
-                                  replicator_pass)
-
-            return replicator_pass
-
-    def run(self, db_version=None, encrypt=None, save_config=True, **kwargs):
+    def run(self, db_version=None, encrypt=None, save_config=True,
+            section='db-server', **kwargs):
         """
         """
         if not db_version:
@@ -166,8 +170,8 @@ class PostgresInstall(Task):
                                     config=self.postgres_config)
         self._restart_db_server(db_version)
         self._setup_ssh_key()
-        self._create_user()
-        self._create_replicator(db_version)
+        self._create_user(section)
+        self._create_replicator(db_version, section)
 
         if save_config:
             env.config_object.save(env.conf_filename)
@@ -192,10 +196,16 @@ class SlaveSetup(PostgresInstall):
 
         return version
 
-    def _get_replicator_pass(self, section='db-server'):
-        password = env.config_object.get_list(section,
+    def _get_replicator_pass(self):
+        try:
+            password = env.config_object.get_list('db-server',
                                              env.config_object.REPLICATOR_PASS)
-        return password[0]
+            return password[0]
+        except:
+            print ("I can't find replicator-password from db-server section "
+                   "of your server.ini file.\n Please set up replicator user "
+                   "in your db-server, and register its info in server.ini")
+            sys.exit(1)
 
     def _setup_recovery_conf(self, master_ip, password, data_dir):
         wal_dir = os.path.join(data_dir, 'wal_archive')
@@ -232,14 +242,15 @@ class SlaveSetup(PostgresInstall):
                 run('sudo su postgres -c "echo %s >> %s"'
                     %(pub_key, authorized_keys))
 
-    def run(self, master=None, encrypt=None, **kwargs):
+    def run(self, master=None, encrypt=None, section=None, **kwargs):
         """
         """
         if not master:
             print "Hey, a master is required for slave."
-            sys.exit()
+            sys.exit(1)
+
+        replicator_pass = self._get_replicator_pass()
 
-        master_ip = master.split('@')[-1]
         db_version = self._get_master_db_version(master=master)
         data_dir = self._get_data_dir(db_version)
         slave = env.host_string
@@ -253,6 +264,7 @@ class SlaveSetup(PostgresInstall):
         self._ssh_key_exchange(master, slave)
 
         with settings(host_string=master):
+            master_ip = run(utils.get_ip_command(None)) # internal ip
 
             run('echo "select pg_start_backup(\'backup\', true)" | sudo su postgres -c \'psql\'')
             run('sudo su postgres -c "rsync -av --exclude postmaster.pid '
@@ -263,7 +275,6 @@ class SlaveSetup(PostgresInstall):
                                     config=self.postgres_config)
         self._setup_archive_dir(data_dir)
 
-        replicator_pass = self._get_replicator_pass()
         self._setup_recovery_conf(master_ip=master_ip,
                                   password=replicator_pass, data_dir=data_dir)
 
@@ -288,7 +299,7 @@ class PGBouncerInstall(Task):
     config = {
         '*':              'host=127.0.0.1',
         'logfile':        '/var/log/pgbouncer/pgbouncer.log',
-        'pidfile':        '/var/run/pgbouncer/pgbouncer.pid',
+        'pidfile':        '/var/pgsql/pgbouncer/pgbouncer.pid',
         'listen_addr':    '*',
         'listen_port':    '6432',
         'unix_socket_dir': '/tmp',
@@ -358,9 +369,9 @@ class PGBouncerInstall(Task):
         sudo('chown -R postgres:postgres %s' %self.config_dir)
 
         # pgbouncer won't run smoothly without these directories
-        sudo('mkdir -p /var/run/pgbouncer')
+        sudo('mkdir -p /var/pgsql/pgbouncer')
         sudo('mkdir -p /var/log/pgbouncer')
-        sudo('chown postgres:postgres /var/run/pgbouncer')
+        sudo('chown postgres:postgres /var/pgsql/pgbouncer')
         sudo('chown postgres:postgres /var/log/pgbouncer')
 
         # set up log
